@@ -28,7 +28,7 @@ async def predict(request):
     user_response = USERMODEL.predict(**request.json)
     response_content = json.dumps(user_response, cls=NumpyEncoder)
     # log here
-    return response.text(content=response_content, media_type="application/json")
+    return response.text(response_content, content_type="application/json")
 
 
 @app.post("/metrics")
